import 'dart:ffi';
import 'dart:typed_data';
import 'dart:io';
import 'dart:async';
import 'package:flutter/services.dart';
import '../live_push_def.dart';

class AlivcLivePlayConfig {
  static MethodChannel methodChannel =
      MethodChannel(AlivcLivePusherInterfaceKey.LivePlayerConfigMethodName);

  /// 创建[AlivcLivePlayConfig]实例
  AlivcLivePlayConfig.init() {}

  /// 设置渲染模式
  ///
  /// [renderMode] 渲染模式
  Future<void> setRenderMode(AlivcLivePlayRenderMode renderMode) async {
    return AlivcLivePlayConfig.methodChannel
        .invokeMethod('setRenderMode', _wrap(arg: renderMode.index.toString()));
  }

  /// 获取渲染模式
  ///
  /// [returns] 渲染模式 默认: [AlivcLivePlayRenderMode.auto]
  Future<AlivcLivePlayRenderMode> getRenderMode() async {
    String strV = await AlivcLivePlayConfig.methodChannel
        .invokeMethod('getRenderMode', _wrap());
    int intV = int.parse(strV);
    return AlivcLivePlayRenderMode.values[intV];
  }

  /// 设置播放是否镜像
  ///
  /// [renderMode] 渲染模式
  Future<void> setMirror(bool mirror) async {
    return AlivcLivePlayConfig.methodChannel.invokeMethod(
        'setMirror', _wrap(arg: AlivcLiveTool.boolToString(mirror)));
  }

  /// 获取播放是否镜像
  ///
  /// [returns] 播放是否镜像 默认: false
  Future<bool> getMirror() async {
    String strV = await AlivcLivePlayConfig.methodChannel
        .invokeMethod('getMirror', _wrap());
    int intV = int.parse(strV);
    return intV == 1 ? true : false;
  }

  /// 设置旋转角度
  ///
  /// [rotationMode] 旋转角度
  Future<void> setRotationMode(AlivcLivePlayRotationMode rotationMode) async {
    return AlivcLivePlayConfig.methodChannel.invokeMethod(
        'setRotationMode', _wrap(arg: rotationMode.index.toString()));
  }

  /// 获取旋转角度
  ///
  /// [returns] 旋转角度 默认: [AlivcLivePlayRotationMode.rotation_0]
  Future<AlivcLivePlayRotationMode> getRotationMode() async {
    String strV = await AlivcLivePlayConfig.methodChannel
        .invokeMethod('getRotationMode', _wrap());
    int intV = int.parse(strV);
    return AlivcLivePlayRotationMode.values[intV];
  }

  /// 播放是否全屏
  Future<void> setIsFullScreen(bool isFullScreen) async {
    return AlivcLivePlayConfig.methodChannel.invokeMethod(
        'isFullScreen', _wrap(arg: AlivcLiveTool.boolToString(isFullScreen)));
  }

  // 接口部分
  _wrap({arg = ''}) {
    var map = {"arg": arg};
    return map;
  }
}
